@@ -72,5 +72,30 @@ jQuery(function($) {
     }
 
     $format_s.on('change', switch_editors);
-    //
+
+
+    // Additional functionality - hiding and showing fieldsets in stranici and
+    // celini forms.
+    $(".mui-form>fieldset>legend").click(function() {
+      let self = this;
+      let rows = $(".mui-row", this.parentNode);
+      let errors = $(".mui-row .field-with-error", this.parentNode);
+      // Hide fieldsets only if there are no validation errors
+      if (rows.is(":visible") && errors.get(0) == null) {
+        rows.hide(600, function() {
+          let text = $(self).text();
+          if (!text.match(/…$/)) $(self).text($(self).text() + "…");
+        });
+      } else {
+        rows.show(600, function() {
+          let text = $(self).text();
+          $(self).text(text.replace(/…/, ""));
+        });
+      }
+    });
+
+    // hide Permissions and additional fields by default.
+    $(".mui-form>fieldset:nth-of-type(2)>legend").click();
+    $(".mui-form>fieldset:nth-of-type(3)>legend").click();
+
 });
